@@ -1,6 +1,6 @@
 /* -*- mode: C; mode: fold; -*- */
 /*
-Copyright (C) 2005-2010 John E. Davis
+Copyright (C) 2005-2021,2022 John E. Davis
 
 This file is part of the S-Lang Library.
 
@@ -23,6 +23,7 @@ USA.
 #include "config.h"
 
 #include <stdio.h>
+#include <string.h>
 #include <errno.h>
 #include <slang.h>
 
@@ -30,22 +31,22 @@ USA.
 
 SLANG_MODULE(png);
 
-static char *Module_Version_String = "0.1.1";
-#define MODULE_VERSION_NUMBER  (0*10000 + 1*100 + 1)
+static SLFUTURE_CONST char *Module_Version_String = "0.2.0";
+#define MODULE_VERSION_NUMBER  (0*10000 + 2*100 + 0)
 
 /*{{{ Byte-swapping routines */
 
 static int Is_Little_Endian;
 
-static void byte_swap32 (unsigned char *p, unsigned char *t, unsigned int n)
+static void byte_swap32 (unsigned char *p, unsigned char *t, SLuindex_Type n)
 {
-   unsigned char *pmax, ch;
+   unsigned char *pmax;
 
    /* t and p could point to the same buffer */
    pmax = p + 4 * n;
    while (p < pmax)
      {
-	ch = *p;
+	unsigned char ch = *p;
 	*t = *(p + 3);
 	*(t + 3) = ch;
 
@@ -57,14 +58,14 @@ static void byte_swap32 (unsigned char *p, unsigned char *t, unsigned int n)
      }
 }
 
-static void byte_swap16 (unsigned char *p, unsigned char *t, unsigned int n)
+static void byte_swap16 (unsigned char *p, unsigned char *t, SLuindex_Type n)
 {
-   unsigned char *pmax, ch;
+   unsigned char *pmax;
 
    pmax = p + 2 * n;
    while (p < pmax)
      {
-	ch = *p;
+	unsigned char ch = *p;
 	*t = *(p + 1);
 	*(t + 1) = ch;
 	p += 2;
@@ -231,7 +232,7 @@ static void fixup_array_rgba (SLang_Array_Type *at)
    unsigned char *data, *data_max;
 
    data = (unsigned char *) at->data;
-   data_max = data + at->num_elements;
+   data_max = data + 4*at->num_elements;
 
    /* RGBARGBA -> ARGBARGB */
    while (data < data_max)
@@ -263,7 +264,7 @@ static SLang_Array_Type *read_image_internal (char *file, int flip, int *color_t
    png_struct *png;
    png_info *info;
    int bit_depth;
-   int interlace_type;
+   /* int interlace_type; */
    int color_type;
    unsigned int sizeof_type;
    SLindex_Type dims[2];
@@ -293,7 +294,7 @@ static SLang_Array_Type *read_image_internal (char *file, int flip, int *color_t
 
    width = png_get_image_width (png, info);
    height = png_get_image_height (png, info);
-   interlace_type = png_get_interlace_type (png, info);
+   /* interlace_type = png_get_interlace_type (png, info); */
    bit_depth = png_get_bit_depth (png, info);
 
    if (bit_depth == 16)
@@ -551,7 +552,7 @@ static int write_array (png_struct *png, png_byte **image_pointers, SLindex_Type
 static int write_image_internal (char *file, SLang_Array_Type *at,
 				 int color_type,
 				 void (*write_fun)(png_struct *, png_byte *p, SLindex_Type, png_byte *),
-				 int flip)
+				 int flip, int compress_level)
 {
    FILE *fp;
    Png_Type *p = NULL;
@@ -608,6 +609,9 @@ static int write_image_internal (char *file, SLang_Array_Type *at,
      }
    png_init_io(png, fp);
 
+   if ((compress_level >= 0) && (compress_level <= 9))
+     png_set_compression_level (png, compress_level);
+
    png_set_IHDR (png, info, width, height,
 		 bit_depth, color_type, PNG_INTERLACE_NONE,
 		 PNG_COMPRESSION_TYPE_BASE, PNG_FILTER_TYPE_BASE);
@@ -642,6 +646,7 @@ static void write_image (int flip)
    SLang_Array_Type *at;
    int with_alpha = 0;
    int has_with_alpha = 0;
+   int compress_level;
    int color_type;
    void (*write_fun) (png_struct *, png_byte *, SLindex_Type, png_byte *);
 
@@ -652,6 +657,9 @@ static void write_image (int flip)
 	has_with_alpha = 1;
      }
 
+   if (-1 == SLang_get_int_qualifier ("compress", &compress_level, -1))
+     return;
+
    if (-1 == SLang_pop_array (&at, 0))
      return;
 
@@ -714,7 +722,7 @@ static void write_image (int flip)
 	SLang_free_array (at);
 	return;
      }
-   (void) write_image_internal (file, at, color_type, write_fun, flip);
+   (void) write_image_internal (file, at, color_type, write_fun, flip, compress_level);
    SLang_free_slstring (file);
    SLang_free_array (at);
 }
