@@ -1,5 +1,5 @@
 /*
-Copyright (C) 2004-2010 John E. Davis
+Copyright (C) 2004-2021,2022 John E. Davis
 
 This file is part of the S-Lang Library.
 
@@ -45,11 +45,11 @@ char *SLmake_string (SLFUTURE_CONST char *str)
    return SLmake_nstring(str, strlen (str));
 }
 
-char *SLmake_nstring (SLFUTURE_CONST char *str, unsigned int n)
+char *SLmake_nstring (SLFUTURE_CONST char *str, SLstrlen_Type n)
 {
    char *ptr;
 
-   if (NULL == (ptr = SLmalloc(n + 1)))
+   if (NULL == (ptr = (char *)SLmalloc(n + 1)))
      {
 	return NULL;
      }
@@ -61,7 +61,7 @@ char *SLmake_nstring (SLFUTURE_CONST char *str, unsigned int n)
 void SLmake_lut (unsigned char *lut, unsigned char *range, unsigned char reverse)
 {
    /* register unsigned char *l = lut, *lmax = lut + 256; */
-   int i, r1, r2;
+   int i, r1;
 
    memset ((char *)lut, reverse, 256);
    /* while (l < lmax) *l++ = reverse; */
@@ -70,7 +70,7 @@ void SLmake_lut (unsigned char *lut, unsigned char *range, unsigned char reverse
    r1 = *range++;
    while (r1)
      {
-	r2 = *range++;
+	int r2 = *range++;
 	if ((r2 == '-') && (*range != 0))
 	  {
 	     r2 = *range++;
@@ -85,7 +85,7 @@ void SLmake_lut (unsigned char *lut, unsigned char *range, unsigned char reverse
 
 char *_pSLskip_whitespace (SLCONST char *s)
 {
-   while (isspace (*s))
+   while (isspace ((unsigned char)*s))
      s++;
 
    return (char *) s;
@@ -97,6 +97,7 @@ char *_pSLskip_whitespace (SLCONST char *s)
 char *_pSLexpand_escaped_char(char *p, char *pmax, SLwchar_Type *ch, int *isunicodep)
 {
    int i = 0;
+   int num_digits_processed = 1;
    SLwchar_Type max = 0;
    SLwchar_Type num, base = 0;
    SLwchar_Type ch1;
@@ -129,22 +130,31 @@ char *_pSLexpand_escaped_char(char *p, char *pmax, SLwchar_Type *ch, int *isunic
 	max = '7';
 	base = 8; i = 2; num = ch1 - '0';
 	break;
+      case '8': case '9':
+	goto malformed_error;
 
       case 'd':			       /* decimal -- S-Lang extension */
 	base = 10;
 	i = 3;
 	max = '9';
 	num = 0;
+	if (p == pmax)
+	  goto malformed_error;
+	num_digits_processed = 0;
 	break;
 
       case 'u':
 	isunicode = 1;
-	/* drop */
+	/* fall through */
       case 'x':			       /* hex */
 	base = 16;
 	max = '9';
-	i = 2;
+	if (isunicode)
+	  i = 4;		       /* \u.... */
+	else
+	  i = 2;
 	num = 0;
+	num_digits_processed = 0;
 
 	if (p == pmax)
 	  goto malformed_error;
@@ -190,11 +200,13 @@ char *_pSLexpand_escaped_char(char *p, char *pmax, SLwchar_Type *ch, int *isunic
 	if ((ch1 <= max) && (ch1 >= '0'))
 	  {
 	     num = base * num + (ch1 - '0');
+	     num_digits_processed++;
 	  }
 	else if (base == 16)
 	  {
 	     ch1 |= 0x20;
 	     if ((ch1 < 'a') || ((ch1 > 'f'))) break;
+	     num_digits_processed++;
 	     num = base * num + 10 + (ch1 - 'a');
 	  }
 	else break;
@@ -208,6 +220,16 @@ char *_pSLexpand_escaped_char(char *p, char *pmax, SLwchar_Type *ch, int *isunic
 	p++;
      }
 
+   if (num_digits_processed == 0)
+     {
+	_pSLang_verror (SL_SYNTAX_ERROR, "Empty \\x or \\d escape sequence seen");
+	return NULL;
+     }
+   if ((base == 10) && (num >= 256))
+     {
+	_pSLang_verror (SL_SYNTAX_ERROR, "\\d escape sequence specifies a byte value arger than 255");
+	return NULL;
+     }
    if (isunicodep != NULL)
      *isunicodep = isunicode;
 
@@ -215,7 +237,7 @@ char *_pSLexpand_escaped_char(char *p, char *pmax, SLwchar_Type *ch, int *isunic
    return p;
 
 malformed_error:
-   _pSLang_verror (SL_SYNTAX_ERROR, "Malformed escaped character.");
+   _pSLang_verror (SL_SYNTAX_ERROR, "Malformed escape sequence.");
    return NULL;
 }
 
@@ -622,7 +644,7 @@ static int hex_atoul (unsigned char *s, unsigned long *ul)
 		  _pSLang_verror (SL_SYNTAX_ERROR, "8 or 9 are not permitted in binary or octal numbers");
 		  return -1;
 	       }
-	     /* drop */
+	     /* fall through */
 	   case '7':
 	   case '6':
 	   case '5':
@@ -634,6 +656,7 @@ static int hex_atoul (unsigned char *s, unsigned long *ul)
 		  _pSLang_verror (SL_SYNTAX_ERROR, "Only digits 0 and 1 are permitted in binary numbers");
 		  return -1;
 	       }
+	     /* fall through */
 	   case '1':
 	   case '0':
 	     ch1 -= '0';
@@ -734,7 +757,7 @@ static int hex_atoull (unsigned char *s, unsigned long long *ul)
 		  _pSLang_verror (SL_SYNTAX_ERROR, "8 or 9 are not permitted in binary or octal numbers");
 		  return -1;
 	       }
-	     /* drop */
+	     /* fall through */
 	   case '7':
 	   case '6':
 	   case '5':
@@ -746,6 +769,7 @@ static int hex_atoull (unsigned char *s, unsigned long long *ul)
 		  _pSLang_verror (SL_SYNTAX_ERROR, "Only digits 0 and 1 are permitted in binary numbers");
 		  return -1;
 	       }
+	     /* fall through */
 	   case '1':
 	   case '0':
 	     ch1 -= '0';
