@@ -1,7 +1,7 @@
 /* -*- mode: C; mode: fold; -*- */
 /* slnspace.c  --- Name Space implementation */
 /*
-Copyright (C) 2004-2010 John E. Davis
+Copyright (C) 2004-2021,2022 John E. Davis
 
 This file is part of the S-Lang Library.
 
@@ -348,8 +348,19 @@ SLang_NameSpace_Type *_pSLns_create_namespace2 (SLFUTURE_CONST char *name, SLFUT
    return ns;
 }
 
+int _pSLns_check_name (SLFUTURE_CONST char *namespace_name)
+{
+   if ((namespace_name == NULL) || (*namespace_name == 0))
+     return 0;
+
+   return _pSLcheck_identifier_syntax (namespace_name);
+}
+
 SLang_NameSpace_Type *SLns_create_namespace (SLFUTURE_CONST char *namespace_name)
 {
+   if (-1 == _pSLns_check_name (namespace_name))
+     return NULL;
+
    return _pSLns_create_namespace2 (NULL, namespace_name);
 }
 
@@ -456,7 +467,7 @@ SLang_NameSpace_Type *_pSLns_find_object_namespace (SLang_Name_Type *nt)
      return NULL;
 
    name = nt->name;
-   hash = _pSLcompute_string_hash (name);
+   hash = SLcompute_string_hash (name);
 
    ns = Namespace_Tables;
    while (ns != NULL)
@@ -477,7 +488,7 @@ SLang_NameSpace_Type *_pSLns_find_object_namespace (SLang_Name_Type *nt)
 
 SLang_Name_Type *_pSLns_locate_name (SLang_NameSpace_Type *ns, SLCONST char *name)
 {
-   return _pSLns_locate_hashed_name (ns, name, _pSLcompute_string_hash (name));
+   return _pSLns_locate_hashed_name (ns, name, SLcompute_string_hash (name));
 }
 
 static void delete_namespace_objects (SLang_NameSpace_Type *ns)
